==> ui-0.2.43.tgz: package/lib/cjs/AssistiveButton/AssistiveButton.js <==
"use strict";

var _WeakMap = require("@babel/runtime-corejs3/core-js-stable/weak-map");
var _Object$defineProperty = require("@babel/runtime-corejs3/core-js-stable/object/define-property");
var _Object$getOwnPropertyDescriptor = require("@babel/runtime-corejs3/core-js-stable/object/get-own-property-descriptor");
var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault");
_Object$defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.AssistiveButton = void 0;
var _indexOf = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/index-of"));
var _getOwnPropertySymbols = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/object/get-own-property-symbols"));
var _assign = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/object/assign"));
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _react = _interopRequireDefault(require("react"));
var _IconBox = require("../IconBox");
var _Loading = require("../Loading");
var Styled = _interopRequireWildcard(require("./AssistiveButton.styled"));
function _getRequireWildcardCache(nodeInterop) { if (typeof _WeakMap !== "function") return null; var cacheBabelInterop = new _WeakMap(); var cacheNodeInterop = new _WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = _Object$defineProperty && _Object$getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? _Object$getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { _Object$defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
var __rest = void 0 && (void 0).__rest || function (s, e) {
  var t = {};
  for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && (0, _indexOf.default)(e).call(e, p) < 0) t[p] = s[p];
  if (s != null && typeof _getOwnPropertySymbols.default === "function") for (var i = 0, p = (0, _getOwnPropertySymbols.default)(s); i < p.length; i++) {
    if ((0, _indexOf.default)(e).call(e, p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
};
const loadingKind = {
  blue: 'primary',
  gray: 'tertiary',
  coral: 'secondary'
};
const AssistiveButton = /*#__PURE__*/_react.default.forwardRef((_a, ref) => {
  var {
      text = '',
      buttonColor = 'blue',
      icon,
      isIconAfter = false,
      disabled = false,
      loading = false,
      children
    } = _a,
    rest = __rest(_a, ["text", "buttonColor", "icon", "isIconAfter", "disabled", "loading", "children"]);
  return (0, _jsxRuntime.jsx)(Styled.DSAssistiveButtonWrapper, (0, _assign.default)({}, rest, {
    ref: ref,
    "$color": buttonColor,
    disabled: disabled || loading,
    "$disabled": disabled || loading
  }, {
    children: loading ? (0, _jsxRuntime.jsx)(_Loading.Loading, {
      kind: loadingKind[buttonColor]
    }) : (0, _jsxRuntime.jsx)(_IconBox.IconBox, {
      text: text || children,
      isIconAfter: isIconAfter,
      icon: icon,
      size: "large"
    })
  }));
});
exports.AssistiveButton = AssistiveButton;
var _default = AssistiveButton;
exports.default = _default;

==> ui-0.2.52.tgz: package/lib/cjs/AssistiveButton/AssistiveButton.js <==
"use strict";

var _WeakMap = require("@babel/runtime-corejs3/core-js-stable/weak-map");
var _Object$defineProperty = require("@babel/runtime-corejs3/core-js-stable/object/define-property");
var _Object$getOwnPropertyDescriptor = require("@babel/runtime-corejs3/core-js-stable/object/get-own-property-descriptor");
var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault");
_Object$defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.AssistiveButton = void 0;
var _indexOf = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/instance/index-of"));
var _getOwnPropertySymbols = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/object/get-own-property-symbols"));
var _assign = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/object/assign"));
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _react = _interopRequireDefault(require("react"));
var _IconBox = require("../IconBox");
var _Loading = require("../Loading");
var Styled = _interopRequireWildcard(require("./AssistiveButton.styled"));
function _getRequireWildcardCache(e) { if ("function" != typeof _WeakMap) return null; var r = new _WeakMap(), t = new _WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = _Object$defineProperty && _Object$getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? _Object$getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? _Object$defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
var __rest = void 0 && (void 0).__rest || function (s, e) {
  var t = {};
  for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && (0, _indexOf.default)(e).call(e, p) < 0) t[p] = s[p];
  if (s != null && typeof _getOwnPropertySymbols.default === "function") for (var i = 0, p = (0, _getOwnPropertySymbols.default)(s); i < p.length; i++) {
    if ((0, _indexOf.default)(e).call(e, p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
};
const loadingKind = {
  blue: 'primary',
  gray: 'tertiary',
  coral: 'secondary'
};
const AssistiveButton = exports.AssistiveButton = /*#__PURE__*/_react.default.forwardRef((_a, ref) => {
  var {
      text = '',
      buttonColor = 'blue',
      icon,
      isIconAfter = false,
      disabled = false,
      loading = false,
      children
    } = _a,
    rest = __rest(_a, ["text", "buttonColor", "icon", "isIconAfter", "disabled", "loading", "children"]);
  return (0, _jsxRuntime.jsx)(Styled.DSAssistiveButtonWrapper, (0, _assign.default)({}, rest, {
    ref: ref,
    "$color": buttonColor,
    disabled: disabled || loading,
    "$disabled": disabled || loading
  }, {
    children: loading ? (0, _jsxRuntime.jsx)(_Loading.Loading, {
      kind: loadingKind[buttonColor]
    }) : (0, _jsxRuntime.jsx)(_IconBox.IconBox, {
      text: text || children,
      isIconAfter: isIconAfter,
      icon: icon,
      size: "large"
    })
  }));
});
var _default = exports.default = AssistiveButton;
